import type { Phone, AuthState } from 'gnuhost-vue3-core/models';
import { Store } from 'pinia';
export type Portal = {
    hrefs: {
        p: string;
        s: string;
        d: string;
    };
    icon: string;
    label: string;
};
export type AuthStoreType = Store<'auth', AuthState, {}, {
    getLoginUrl(redirectPath?: string): string;
    register(model: RegisterationFormModel, returnUrl?: string): Promise<void>;
    login(model: LoginFormModel, returnUrl?: string): Promise<void>;
    logout(): Promise<void>;
}>;
export type RegisterationFormModel = {
    email: string;
    password: string;
    first_name: string;
    last_name: string;
    street: string;
    city: string;
    state: string;
    zip_code: string;
    country: string;
    phone_number: string;
    street2: string | undefined | null;
    company_name: string | undefined | null;
    vat_number: string | undefined | null;
    website: string | undefined | null;
    _phone: Phone;
    _confirm_password: string;
};
export type LoginFormModel = {
    email: string;
    pass: string;
};
export type InventoryItem = {
    inventory_id: string;
    created_at: Date;
    client: string;
    item_type: string;
    item_model: string;
    item_url: string;
    item_name: string;
    item_ip: string;
    item_description: string;
    item_price: number;
    addon_description: string;
    parent_id: string;
    admin_notes: string;
    status: string;
    provider_code: string;
    provider_model: string;
    filter_ip: string;
};
export type InventoryItemModel = {
    created_at: Date;
    item_type: string;
    item_model: string;
    producer: string | undefined | null;
    m_label: string | undefined | null;
    ram: number | undefined | null;
    cpu_count: number | undefined | null;
    cpu_cores: number | undefined | null;
    cpu_speed: number | undefined | null;
    cpu_model: string | undefined | null;
    disk_count: number | undefined | null;
    disk_gb: number | undefined | null;
    disk_type: string | undefined | null;
    cost: number | undefined | null;
    price: number;
    admin_notes: string | undefined;
};
export type InventoryItemModelCreate = Omit<InventoryItemModel, 'created_at'>;
export type InventoryItemType = {
    item_type: string;
    type_name: string;
};
export type InventoryDiskType = {
    disk_type: string;
    type_name: string;
    tag: string;
};
export type InventoryItemModelMapping = {
    provider: string;
    their_model: string;
    our_model: string;
    our_type: string;
    their_price: number;
};
export type InventoryClientDiscount = {
    discount_id: string;
    client_id: string;
    created_at: Date;
    created_by: string;
    item_type: string;
    item_model: string;
    percent: number;
    original_price: number;
    new_price: number;
    start_dt: Date;
    end_dt: Date;
};
export type ClientProduct = {
    inventory_id: number;
    username: string;
    item_type_id: number;
    item_type: string;
    item_price: number;
    item_name: string;
    item_url: string;
    item_description: string;
    parent_id?: number;
};
export type OfferTag = {
    offer_tag_id: number;
    name: string;
};
export type Offer = {
    offer_id: number;
    producer: string;
    label: string;
    cpu_model: string;
    cpu_count: number;
    cpu_cores: number;
    ram: number;
    disk_count: number;
    disk_gb: number;
    disk_type: string;
    disk_tag: string;
    location: Array<string>;
    description: string | undefined | null;
    price: number;
    tags: Array<string>;
};
export type OfferCreate = Omit<Offer, 'offer_id' | 'disk_tag'>;
export type OrderItem = {
    item_id: number;
    item_name: string;
    item_price: number;
    quantity: number;
    total: number;
};
export type OrderItemCreate = {
    p_order_id: string;
    p_offer_id: number;
    p_quantity: number;
};
export type OrderStatus = {
    Status: string;
};
export type Order = {
    order_id: string;
    created_at: Date;
    created_by: string;
    username?: string;
    total: number;
    status: string;
    items: Array<OrderItem>;
    _selected_items: Array<OrderItem>;
};
export declare const OrderExportColumns: string[];
export type OrderCreate = {
    p_order_id: string | undefined | null;
    p_offer_id: number | undefined | null;
    p_item_name: string | undefined | null;
    p_item_price: number | undefined | null;
    p_quantity: number;
};
export type ClusterVM = {
    id: number;
    cluster: string;
    prox: number;
    vmid: number;
    client: string;
    name: string;
    port: number;
    state: string;
    ram: number;
    disk: number;
    ip: string;
    mac: string;
    cores: number;
    ipsets: string;
    type: string | undefined | null;
    model: string | undefined | null;
    url: string | undefined | null;
    notes: string | undefined | null;
    client_notes: string | undefined | null;
    is_locked: boolean;
    _ram_gigabytes: number;
};
export type ClusterIp = {
    ip: string;
    comment: string;
};
export type ClusterIpset = {
    ipset: number;
    client: string;
    name: string;
    comment: string;
    _allowed_ips: Array<string>;
};
export type ClusterIpsetCreate = Omit<ClusterIpset, 'ipset' | 'client'>;
export type AddIpArrayToIpset = {
    p_ipset: number;
    p_ips: Array<string>;
};
export type ClusterIpsetIp = {
    ipset: number;
    ip: string;
};
export type ClusterIpsetVm = {
    id: number;
    ipset: number;
    vmid: number;
    cluster: string;
};
