import { type AxiosInstance } from 'axios';
import { type PagedEnumerable, type PaginationOptions, type KeyValuePair, type EnvironmentVariables } from 'gnuhost-vue3-core/models';
import { AuthStoreType } from '../models';
export declare class ApiEndpoint {
    readonly partialUrl: string;
    readonly isPublic: boolean;
    readonly includeAuthHeader: boolean;
    selectColumns?: Array<string>;
    searchParams?: Array<string>;
    paginationOptions?: PaginationOptions;
    constructor(partial_url: string, is_public: boolean, include_auth_header: boolean);
    url(env: EnvironmentVariables): string;
}
export type ApiServiceOptions = EnvironmentVariables & {
    authStore: AuthStoreType;
    axiosInstance: AxiosInstance;
};
declare class ApiServiceClass {
    private static _instance;
    static get Instance(): ApiServiceClass;
    private readonly BOM;
    private constructor();
    private isUser;
    private initHeader;
    private sanitizePayload;
    private export;
    private options;
    configureApiServiceOptions(options: ApiServiceOptions): void;
    getPagedCollectionFromCacheOrDb<T>(endpoint: ApiEndpoint, payload?: any | null | undefined, accept?: string, customHeaders?: Array<KeyValuePair>, isExport?: boolean, exportFileName?: string): Promise<PagedEnumerable<T>>;
    exportPagedCollectionFromCacheOrDb<T>(endpoint: ApiEndpoint, exportFileName: string, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<PagedEnumerable<T>>;
    getPagedCollection<T>(endpoint: ApiEndpoint, accept?: string, customHeaders?: Array<KeyValuePair>, isExport?: boolean, exportFileName?: string): Promise<PagedEnumerable<T>>;
    exportPagedCollection<T>(endpoint: ApiEndpoint, exportFileName: string, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<PagedEnumerable<T>>;
    getPagedCollectionByPost<T>(endpoint: ApiEndpoint, payload?: any | null | undefined, accept?: string, customHeaders?: Array<KeyValuePair>, isExport?: boolean, exportFileName?: string): Promise<PagedEnumerable<T>>;
    private _getCollectionResponse;
    getCollection<T>(endpoint: ApiEndpoint, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<any>;
    getCollectionByPost<T>(endpoint: ApiEndpoint, payload?: any, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<T[]>;
    getSingle<T>(endpoint: ApiEndpoint, customHeaders?: Array<KeyValuePair>): Promise<T | null>;
    post<T>(endpoint: ApiEndpoint, payload: T, returnType?: string, customHeaders?: Array<KeyValuePair>): Promise<import("axios").AxiosResponse<any, any>>;
    put<T>(endpoint: ApiEndpoint, payload: T, returnType?: string, customHeaders?: Array<KeyValuePair>): Promise<import("axios").AxiosResponse<any, any>>;
    patch<T>(endpoint: ApiEndpoint, payload: T, returnType?: string, customHeaders?: Array<KeyValuePair>): Promise<import("axios").AxiosResponse<any, any>>;
    delete(endpoint: ApiEndpoint, customHeaders?: Array<KeyValuePair>): Promise<number>;
}
export declare const ApiService: ApiServiceClass;
export {};
